## Overview

This Python package provides code regarding the RDG networks project.

[![License](https://img.shields.io/badge/license-MIT-blue.svg)](https://opensource.org/licenses/MIT)
[![Python Version](https://img.shields.io/badge/python-3.6%2B-blue.svg)](https://www.python.org/downloads/)

## Table of Contents

- [Features](#features)
- [Installation](#installation)
- [Usage](#usage)
- [Configuration](#configuration)
- [License](#license)
- [Contact](#contact)

## Features

- **generate_line_segments:** Function that determines the linesegments of a RDG network.
- **generate_line_network:** Function that makes the underlying network of the linesegments.
- **get_intersection_segments:** Function that determines the intersection segments of a RDG network.
- **draw_segments:** Function that draws the segments.


## Installation
You can install the package using pip:

```bash
pip install RDG-networks
```

## Usage
To use the package, import the relevant script from the functions folder based on the algorithm you'd like to apply.

## Configuration
No specific configuration is required.

## License
This package is distributed under the MIT license.

## Contact
You can contact me at mooij.niek@gmail.com for any questions or suggestions.